% m-file to read volume matrix of anomalous subsurface density structure
% as output by GROWTH2.0
%code creates a 3D representation of the subsurface density anomaly
%structure

%%%%%%%
%J. Gottsmann, Univ. Bristol, November 2010
%renamed and modified by P. MacQueen April 2013 to better fight
%with matlab.






%% Define parameters

clear all
% close all

%Define the matrix geometry with headers files from Growth Mat.dat file

mtx=[60 60 31]; %read from MAT.dat file [rows, columns, pages]

Emin= 512196;      % define minimum Easting
Emax= 543938;      % define maximum Easting

Nmin= 1364788;      % define minimum Northing
Nmax= 1396530;      % define maximum Northing

Dmin= -15963;      % define minimum Depth
Dmax= 177;      % define maximim Depth

% define axis separation 
dE=(Emax-Emin)/(mtx(1)-1);
dN=(Nmax-Nmin)/(mtx(2)-1);
dD=(Dmax-Dmin)/(mtx(3)-1);

%Define axes
x=Emin:dE:Emax;
y=Nmin:dN:Nmax;
z=Dmin:dD:Dmax;

[X,Y,Z]=meshgrid(x,y,z);


%% Load Density structure
% Density structure needs to be saved in a .txt file with the header lines
% provided in the original .dat file by Growth removed

Vall=load('ThMATAll.txt'); %text file with data


V=Vall;

A=zeros(mtx(2),mtx(1),mtx(3));

%turn data into volume data
for  j=1:mtx(3);
    xcounter=(j-1)*mtx(2)+1:j*mtx(2);
    ycounter=1:mtx(1);
    res=V((j-1)*mtx(2)+1:j*mtx(2),1:mtx(1));
    A(:,:,j)=res;
end
    
A(A>=999)=NaN; %turns all those pesky 9999 values into NaN so isosurfaces work properly


%% Load topography data
 
%load gridded topgraphic data from xyz file

topog=load('MatlabAllDEM.xyz'); %xyz file with topo data
topogx=min(topog(:,1)):15:max(topog(:,1));
topogy=min(topog(:,2)):15:max(topog(:,2));
topogz=min(topog(:,3)):15:max(topog(:,3));
[TX,TY]=meshgrid(topogx,topogy);
TZfun=TriScatteredInterp(topog(:,1),topog(:,2),topog(:,3));
TZ=TZfun(TX,TY);


%% Plot positive anomalies 

posdes=140; %positive density cutoff

figure('name','Density Anomalies')

fvpos=isosurface(X,Y,Z,A,posdes);hold on %define isosurface for given density contrast in kg/m3
light
p=patch(fvpos);
set(p,'Facecolor', [.8,.5,.0], 'Edgecolor', 'none');
material shiny
lighting gouraud
%orange 1 0.5 0.2
%goldenrod .8,.5,.0
fvpc=isocaps(X,Y,Z,A,posdes);hold on %define caps on the isosurface for given density contrast in kg/m3
light
p=patch(fvpc);
set(p,'Facecolor', [.8,.5,.0], 'Edgecolor', 'none');
material shiny
lighting gouraud


grid on
%% Figure labels
xlabel('Easting, m','FontSize',20)
ylabel('Northing, m','FontSize',20)
zlabel('Elevation, m','FontSize',20)
title({'Cerro Negro Density Anomalies';'Isosurfaces at -2120, and 2700 kg m^{-3}'},'FontSize',20);

%% plot negative anomalies

negdes=-440; %negative density cutoff

fvneg=isosurface(X,Y,Z,A,negdes);hold on %define isosurface for given density contrast in kg/m3
light
p=patch(fvneg);
set(p,'Facecolor', [.25,.4,.6], 'Edgecolor', 'none');
material shiny
lighting gouraud



%% Plot topography

contour3(TX,TY,TZ,30,'k');hold on
topoh = findobj('Type','patch');
set(topoh,'LineWidth',1)
dar=[1 cos(19.5*pi/180) 1];
daspect(dar);

%% constrain axis to match topography
axis([min(topog(:,1)) max(topog(:,1)), min(topog(:,2)) max(topog(:,2)), -8000 max(topog(:,3))]) %use for entire survey area
%axis([Emin+50000 Emax-60000, Nmin+60000 Nmax-50000, Dmin Dmax+6000])

%% Plot Faults
%Plots faults.  Faults are specified in a matrix where column 1 is the
%fault number, column 2 is the number of the point in its fault, column 3
%is the easting of the individual fault point, and column 4 is the northing
%of the individual fault point
load CNF %load fault data
%plot faults as indiviual lines
for i=1:max(CNF(:,1))
    faultind=find(CNF(:,1)==i); %find all the coordinates corresponding to fault i
    heights(1:length(faultind),1)=max(topog(:,3));
    plot3(CNF(faultind,3),CNF(faultind,4),heights,'k','LineWidth',2)
    clear heights
end
%% Plot other things

plot3(532378,1382525,800,'^r','MarkerFaceColor','r','MarkerSize',15)%Location of CN

%plot station locations
load('GravLoc.mat');
UTMstat=GravLoc;
instat=UTMstat(find(UTMstat(:,1)>=min(topog(:,1))&UTMstat(:,1)<=max(topog(:,1))&UTMstat(:,2)>=min(topog(:,2))&UTMstat(:,2)<=max(topog(:,2))),:);
plot3(instat(:,1),instat(:,2),instat(:,3),'k.','MarkerSize',20)

view(3)
%% Transparent other levels
%Plots additional surfaces as transparent isosurfaces after the first isosurface has been plotted
alpha(0.75)

posdes2=340;
posdes3=440;
%surface2
fvpos2=isosurface(X,Y,Z,A,posdes2);hold on %define isosurface for given density contrast in kg/m3
light
p=patch(fvpos2);
set(p,'Facecolor', [1 0.5 0.2], 'Edgecolor', 'none');%makes it orange
material shiny
lighting gouraud

fvpc2=isocaps(X,Y,Z,A,posdes2);hold on %define caps on the isosurface for given density contrast in kg/m3
light
p=patch(fvpc2);
set(p,'Facecolor', [1 0.5 0.2], 'Edgecolor', 'none');
material shiny
lighting gouraud

alpha(0.5)

%surface3
fvpos3=isosurface(X,Y,Z,A,posdes3);hold on %define isosurface for given density contrast in kg/m3
light
p=patch(fvpos3);
set(p,'Facecolor', 'red', 'Edgecolor', 'none');
material shiny
lighting gouraud

fvpc3=isocaps(X,Y,Z,A,posdes3);hold on %define caps on the isosurface for given density contrast in kg/m3
light
p=patch(fvpc3);
set(p,'Facecolor', 'red', 'Edgecolor', 'none');
material shiny
lighting gouraud


%%  animation

%make an 3D animation of the sub-surfac structure



mov=avifile('UTU','compression','none');


for i=1:100;
    
  view(-37.5+4*(i-1),6); grid on
   F(i)=getframe(gcf); 
    
end
mov=addframe(mov,F);

mov=close(mov);

movie(F)
movie2avi(F,'UTU.avi','compression','none');