%GrowthVolume.m
%For calculating volumes from the Growth mod file
%requires csv file of model with all values rescaled and cell volumes
%calculated and bounds of anomalies of interest
%
%
%-----------------------------------------------------------------------------
%Code written by Patricia MacQueen (pmacquee@gmail.com), December 6, 2013.
%If you use this code, please credit me appropriately.
%-----------------------------------------------------------------------------



%% Load Data
%load data reformatted from mod.dat file.  See Growth help file (GROWTH.txt) for how to
%rescale data
%data should be in a .csv file with one header line.  Columns are x,y,z side, y side, top z, bot z, density, cell volume
filename='OptiModScaled.csv';
FM=csvread(filename,2,1);%reads data beginning after one header line
%% Selection Calculation Area Segments
%carve out xy areas of interest

%CN anomaly
CNn=1.3826e+006; %northern extent of anomaly (UTM)
CNs=1.3801e+006; %southern extent of anomaly (UTM)
CNw=5.3115e+005; %western extent of anomaly (UTM)
CNe= 5.3397e+005; %eastern extent of anomaly (UTM)

%LPEH anomaly
LPHn=1.3846e+006;
LPHs=1.3801e+006;
LPHw=5.3397e+005;
LPHe=5.3665e+005;

%CLM anomaly
CLMn=1.3858e+006;
CLMs=1.3835e+006;
CLMw=5.3115e+005;
CLMe=5.3397e+005;

%create new variable with cells around CN anomaly only
CNcells=FM(FM(:,1)<=CNe&FM(:,1)>=CNw&FM(:,2)<=CNn&FM(:,2)>=CNs,:);

%create new variable with cells around LPEH anomaly only
LPHcells=FM(FM(:,1)<=LPHe&FM(:,1)>=LPHw&FM(:,2)<=LPHn&FM(:,2)>=LPHs,:);

%create new variable with cells around CLM anomaly only
CLMcells=FM(FM(:,1)<=CLMe&FM(:,1)>=CLMw&FM(:,2)<=CLMn&FM(:,2)>=CLMs,:);

%% Calculate Volumes
%calculate volumes
cutoff=440; %minimum density for positive anomaly
VolCN=sum(CNcells(CNcells(:,7)>cutoff,8));
VolLPH=sum(LPHcells(LPHcells(:,7)>cutoff,8));
VolCLM=sum(CLMcells(CLMcells(:,7)>cutoff,8));


%% Check Calculation Ranges
%find out what you actually calculated the volume of
%plots x,y,average of ztop and zbot for each cell used in volume
%calculation
figure('name','CN Anomaly')
plot3(CNcells(CNcells(:,7)>cutoff,1),CNcells(CNcells(:,7)>cutoff,2),mean([CNcells(CNcells(:,7)>cutoff,5) CNcells(CNcells(:,7)>cutoff,6)],2),'*');

figure('name','LPEH Anomaly')
plot3(LPHcells(LPHcells(:,7)>cutoff,1),LPHcells(LPHcells(:,7)>cutoff,2),mean([LPHcells(LPHcells(:,7)>cutoff,5) LPHcells(LPHcells(:,7)>cutoff,6)],2),'*');

figure('name','CLM Anomaly')
plot3(CLMcells(CLMcells(:,7)>cutoff,1),CLMcells(CLMcells(:,7)>cutoff,2),mean([CLMcells(CLMcells(:,7)>cutoff,5) CLMcells(CLMcells(:,7)>cutoff,6)],2),'*');