function growthformat(infile,outfile)
%converts my data from variables in Matlab to something GROWTH can read.
%
%Exports a file "outfile.dat" in format GROWTH likes
%
% inputs:infile = string of input filename, e.g. 'filename.csv'.  File should be
%           in .csv format, with no headers, and column order
%           x,y,z,grav,graverror,terrain
%        outfile = string of output filename, 'filename.dat' (include .dat in filename) 
%        x = x coordinates of gravity stations (assumes coordinates in UTM)
%        y = y coordinates of gravity stations
%        z = altitudes of gravity stations (negative below sea level)
%        grav = gravity anomaly values in microgal (ie, after free air etc corrections)
%               for each station
%        graverror = estimation of error at east station in mgal
%                    (optional for program, can be bogus values unless desired)
%        terrain = value of terrain correction in microgal at each station
%                  (also optional)
%
%
%-----------------------------------------------------------------------------
%Code written by Patricia MacQueen (pmacquee@gmail.com), December 6, 2013.
%If you use this code, please credit me appropriately.
%-----------------------------------------------------------------------------

%load data from .csv file
gdata=csvread(infile);
%split up data file into variables
x=gdata(:,1);
y=gdata(:,2);
z=gdata(:,3);
grav=gdata(:,4);
graverror=gdata(:,5);
terrain=gdata(:,6);

% reformat and write to file
squid=fopen(outfile,'wt'); %open output file writing to
%write things to file in the proper format
for i=1:length(x)
    fprintf(squid,'%#-7.0f %#-9.0f %#-8.2f %#-9.0f %#-5.1f %#-8.3f\r\n',x(i),y(i),z(i),grav(i)*1000,graverror(i)*1000,terrain(i));
end
fprintf(squid,'0 0 0 0 0 0');%Growth requires the file to end with 0s
fclose(squid);%close file.